/****************************************************************************
 *	This is the class representing all visual information
 *	Members are public since this are only data containers
 ***************************************************************************/
package com.ls.research.robocup.perception;

import java.util.StringTokenizer;

public class AudibelInfo
{
	public static final int NO_OF_PLAYMODES		= 21;
	// playmodes 
	public static final int BEFORE_KICK_OFF		= 1;
	public static final int TIME_OVER			= 2;
	public static final int PLAY_ON				= 3;
	public static final int KICK_OFF_L			= 4;
	public static final int KICK_OFF_R			= 5;
	public static final int KICK_IN_L			= 6;
	public static final int KICK_IN_R			= 7;
	public static final int FREE_KICK_L			= 8;
	public static final int FREE_KICK_R			= 9;
	public static final int CORNER_KICK_L		= 10;
	public static final int CORNER_KICK_R		= 11;
	public static final int GOAL_KICK_L			= 12;
	public static final int GOAL_KICK_R			= 13;
	public static final int GOAL_L				= 14;
	public static final int GOAL_R				= 15;
	public static final int DROP_BALL			= 16;
	public static final int OFFSIDE_L			= 17;
	public static final int OFFSIDE_R			= 18;
	public static final int CATCH_L				= 19;
	public static final int CATCH_R				= 20;

	public static final int HALF_TIME			= 20;
	public static final int EXTEND				= 21;
	public static final int FOUL_L				= 22;
	public static final int FOUL_R				= 23;


	public static final String[] PLAYMODE_STRINGS = {"",
														"before_kick_off",
														"time_over",
														"play_on",
														"kick_off_l",
														"kick_off_r",
														"kick_in_l",
														"kick_in_r",
														"free_kick_l",
														"free_kick_r",
														"corner_kick_l",
														"corner_kick_r",
														"goal_kick_l",
														"goal_kick_r",
														"goal_l",
														"goal_r",
														"drop_ball",
														"offside_l",
														"offside_r",
														"goalie_catch_ball_l",
														"goalie_catch_ball_r"
													};

	public static final int	AUDIBLE_TYPE_REFEREE	= 0;
	public static final int	AUDIBLE_TYPE_PLAYER		= 1;
	public static final int	AUDIBLE_TYPE_SELF		= 2;

	public	int				m_time;
	public	char			m_type;
	public	int				m_playmode;
	public	String			m_message;
	
	private	StringTokenizer	m_tokenizer;

	/**
	 * Constructor receiving the visual message
	 * 
	 * @param	info	visual message received by the server
	 */
	public AudibelInfo(String info)
	{
		info.trim();
		m_message = info;
		m_tokenizer = new StringTokenizer(info,"() ", true);
		System.out.println(info);
	}

	/**
	 * Parses the visual string into java objects
	 */
	public void parse()
	{
		String 		token = null;
		ObjectInfo	objInfo;


		try
		{
			// First is '('
			m_tokenizer.nextToken();	
			// then we should find hear
			m_tokenizer.nextToken();
			// now ' ' followed by time and ' '
			m_tokenizer.nextToken();	
			m_time = Integer.parseInt( m_tokenizer.nextToken() );
			m_tokenizer.nextToken();	

			// then we should find who sent the message
			token = m_tokenizer.nextToken();
			
			if (token.equals("referee")) {				
				m_type = AUDIBLE_TYPE_REFEREE;
				token = m_tokenizer.nextToken();
				int 	mode 	= 0;
				while ((mode < NO_OF_PLAYMODES) && (!token.equals(PLAYMODE_STRINGS[mode])))
					mode++;

				if (mode < NO_OF_PLAYMODES)	{
					// set the playmode
					m_playmode = mode;
				
				} else {
					// check if it is a goal, because goals have different text
					if (token.startsWith(PLAYMODE_STRINGS[GOAL_L]))
						m_playmode = GOAL_L;
					else if (token.startsWith(PLAYMODE_STRINGS[GOAL_R]))
						m_playmode = GOAL_R;
				}
			
			} else if (token.startsWith("s")) {
				// a message sent by my own
				m_type = AUDIBLE_TYPE_SELF;
			
			} else {
				// a message sent by any other player
				m_type = AUDIBLE_TYPE_PLAYER;
			}
		
		} catch(Exception e) {
			System.out.println("Error parsing hear information");
			System.out.println(token);
			while( m_tokenizer.hasMoreTokens() )
				System.out.print(m_tokenizer.nextToken());

			System.out.println("");
		}
	}
}