//***************************************************************************
//
//	This interface declares functions which are used to notify a player
//  of low level information received
//
//***************************************************************************

package com.ls.research.robocup.perception;

import java.util.HashMap;

public interface PerceptionInterface
{
	String[] server_param =
	{
	 "gwidth", "inertia_moment", "psize", "pdecay", "prand", "pweight",
	 "pspeed_max", "paccel_max", "stamina_max", "stamina_inc", "recover_init",
	 "recover_dthr", "recover_min", "recover_dec", "effort_init", "effort_dthr",
	 "effort_min", "effort_dec", "effort_ithr", "effort_inc", "kick_rand",
	 "team_actuator_noise", "prand_factor_l", "prand_factor_r","kick_rand_factor_l",
	 "kick_rand_factor_r", "bsize", "bdecay", "brand", "bweight", "bspeed_max",
	 "baccel_max", "dprate", "kprate", "kmargin", "ctlradius", "ctlradius_width",
	 "maxp", "minp", "maxm", "minm", "maxnm", "minnm", "maxn", "minn", "visangle",
	 "visdist", "windir", "winforce", "winang", "winrand", "kickable_area",
	 "catch_area_l", "catch_area_w", "catch_prob", "goalie_max_moves", "ckmargin",
	 "offside_area", "win_no", "win_random", "say_cnt_max", "SayCoachMsgSize",
	 "clang_win_size", "clang_define_win", "clang_meta_win",
	 "clang_advice_win", "clang_info_win", "clang_mess_delay", "clang_mess_per_cycle",
	 "half_time", "sim_st", "send_st", "recv_st", "sb_step", "lcm_st", "SayMsgSize",
	 "hear_max", "hear_inc", "hear_decay", "cban_cycle", "slow_down_factor",
	 "useoffside", "kickoffoffside", "offside_kick_margin", "audio_dist", "dist_qstep",
	 "land_qstep", "dir_qstep", "dist_qstep_l", "dist_qstep_r", "land_qstep_l",
	 "land_qstep_r", "dir_qstep_l", "dir_qstep_r", "CoachMode", "CwRMode", "old_hear",
	 "sv_st", "doNotKnow1", "doNotKnow2", "doNotKnow3", "doNotKnow4", "doNotKnow5"
	};


	String[] player_param =
	{
	 "player_types", "subs_max", "pt_max",
	 "player_speed_max_delta_min", "player_speed_max_delta_max",
	 "stamina_inc_max_delta_factor", "player_decay_delta_min",
	 "player_decay_delta_max", "inertia_moment_delta_factor",
	 "dash_power_rate_delta_min", "dash_power_rate_delta_max",
	 "player_size_delta_factor", "kickable_margin_delta_min",
	 "kickable_margin_delta_max", "kick_rand_delta_factor",
	 "extra_stamina_delta_min", "extra_stamina_delta_max",
	 "effort_max_delta_factor", "effort_min_delta_factor"
	};

	String[] player_type =
	{
	 "id", "player_speed_max", "stamina_inc_max", "player_decay",
	 "inertia_moment", "dash_power_rate", "player_size", "kickable_margin",
	 "kick_rand", "extra_stamina", "effort_max", "effort_min",
	};

	/**
	 * Called when new see information arrived from the server
	 *
	 * @param visual	parsed see message of the server
	 */
	public void onSee(VisualInfo visual);

	/**
	 * Called when new hear information arrived from the server
	 *
	 * @param audibel	parsed hear message of the server
	 */
	public void onHear(AudibelInfo audibel);

	/**
	 * Called when new sense body information arrived from the server
	 *
	 * @param propriozeption	parsed sense body message of the server
	 */
	public void onSenseBody(PropriozeptiveInfo propriozeption);

	/**
	 * Called when init information arrived from the server
	 *
	 * @param side		side on which the player plays l|r
	 * @param number	number of the player
	 * @param playmode	the current playmode
	 */
	public void onInit(char side, int number, String playmode);

	/**
	 * Called when the server parameter information is received at the start of the game
	 *
	 * @param parameters	parameters of the server stored in a hashmap
	 */
	public void onServerParam(HashMap parameters);

	/**
	 * Called when the parameter information of the player is received
	 *
	 * @param parameters	parameters of the player stored in a hashmap
	 */
	public void onPlayerParam(HashMap parameters);

	/**
	 * Called when the player type information of the player is received
	 *
	 * @param parameters	parameters of the player type stored in a hashmap
	 */
	public void onPlayerType(HashMap parameters);

	/**
	 * Called when a player changed type
	 *
	 * @param number	number of the player that changed
	 * @param type		the new type of the player, if the player is of our own team
	 *					ObjectInfo.NOT_EXISTING if the player is of the other team
	 */
	public void onChangePlayer(int number, int type);

	/**
	 * Called when a player received score information in reaction to a score command
	 *
	 * @param time		the time of the server
	 * @param left		score of the left team at time
	 * @param right		score of the right team at time
	 */
	public void onScore(int time, int left, int right);

	/**
	 * Called when any other that the previos messages arrived such as init or error
	 *
	 * @param message	unparsed message of the server
	 */
	public void onMessage(String message);
}
