//***************************************************************************
//
//	This interface declares functions which are used to notify a player
//  of low level information received
//
//***************************************************************************

package com.ls.research.robocup.server;

public interface SoccerPerceptionInterface
{
	/**
	 * Called when new see information arrived from the server
	 *
	 * @param message	unparsed see message of the server
	 */
	public void onSee(String message);

	/**
	 * Called when new hear information arrived from the server
	 *
	 * @param message	unparsed hear message of the server
	 */
	public void onHear(String message);

	/**
	 * Called when new sense body information arrived from the server
	 *
	 * @param message	unparsed sense body message of the server
	 */
	public void onSenseBody(String message);

	/**
	 * Called when the init information arrived from the server
	 *
	 * @param message	unparsed init information of the server
	 */
	public void onInit(String message);

	/**
	 * Called when the server parameter information is received at the start of the game
	 *
	 * @param message	unparsed parameter information of the server
	 */
	public void onServerParam(String message);

	/**
	 * Called when the parameter information of the player is received
	 *
	 * @param message	unparsed parameter information of the player
	 */
	public void onPlayerParam(String message);

	/**
	 * Called when the player type information of players is received
	 *
	 * @param message	unparsed player type information
	 */
	public void onPlayerType(String message);

	/**
	 * Called when the a player changed type
	 *
	 * @param message	unparsed change type information of the server
	 */
	public void onChangePlayer(String message);

	/**
	 * Called when the player receives the score of the game after sending score action
	 *
	 * @param message	unparsed score information of the server
	 */
	public void onScore(String message);

	/**
	 * Called when any other that the previos messages arrived such as error
	 *
	 * @param message	unparsed message of the server
	 */
	public void onMessage(String message);
}
